@@ -1,4 +1,6 @@
 import base64
+import six
+import struct
 
 
 def base64url_decode(input):
